==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/rg/data_rg_list_deleted/main.tf <==
/*
Пример использования
Получение информации о списке удаленных ресурсных групп
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_rg_list_deleted" "list_deleted" {
  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка ресурсных групп
  #опциональный параметр
  #тип - целое число
  #account_id = 11111

  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "test"

  #фильтр по времени создания (после указанного времени)
  #опциональный параметр
  #тип - целое число
  #created_after = "123"

  #фильтр по времени создания (перед указанным временем)
  #опциональный параметр
  #тип - целое число
  #created_before = "123"

  #фильтр по lock status
  #опциональный параметр
  #тип - строка
  #lock_status = "UNLOCKED"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы
  #опциональный параметр
  #тип - целое число
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #size = 2
}

output "output" {
  value = data.dynamix_rg_list_deleted.list_deleted
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/rg/data_rg_list_deleted/main.tf <==
/*
Пример использования
Получение информации о списке удаленных ресурсных групп
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_rg_list_deleted" "list_deleted" {
  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка ресурсных групп
  #опциональный параметр
  #тип - целое число
  #account_id = 11111

  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #account_name = "test"

  #фильтр по времени создания (после указанного времени)
  #опциональный параметр
  #тип - целое число
  #created_after = "123"

  #фильтр по времени создания (перед указанным временем)
  #опциональный параметр
  #тип - целое число
  #created_before = "123"

  #фильтр по lock status
  #опциональный параметр
  #тип - строка
  #lock_status = "UNLOCKED"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы
  #опциональный параметр
  #тип - целое число
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #size = 2
}

output "output" {
  value = data.dynamix_rg_list_deleted.list_deleted
}
